@@ -223,6 +223,8 @@ def loadcontext(object_type, uri, name=None, relative_to=None,
             uri = uri.split('#', 1)[0]
     if name is None:
         name = 'main'
+    if ':' not in uri:
+        raise LookupError("URI has no scheme: %r" % uri)
     scheme, path = uri.split(':', 1)
     scheme = scheme.lower()
     if scheme not in _loaders:
@@ -260,6 +262,8 @@ def _loadconfig(object_type, uri, path, name, relative_to,
         path = path[2:]
     path = urllib.unquote(path)
     loader = ConfigLoader(path)
+    if global_conf:
+        loader.update_defaults(global_conf, overwrite=False)
     return loader.get_context(object_type, name, global_conf)
 
 _loaders['config'] = _loadconfig
@@ -313,7 +317,7 @@ class _Loader(object):
 class ConfigLoader(_Loader):
 
     def __init__(self, filename):
-        self.filename = filename
+        self.filename = filename = filename.strip()
         self.parser = NicerConfigParser(self.filename)
         # Don't lower-case keys:
         self.parser.optionxform = str
@@ -321,13 +325,19 @@ class ConfigLoader(_Loader):
         # we have to add an extra check:
         if not os.path.exists(filename):
             raise OSError(
-                "File %s not found" % filename)
+                "File %r not found" % filename)
         self.parser.read(filename)
         self.parser._defaults.setdefault(
             'here', os.path.dirname(os.path.abspath(filename)))
         self.parser._defaults.setdefault(
             '__file__', os.path.abspath(filename))
 
+    def update_defaults(self, new_defaults, overwrite=True):
+        for key, value in new_defaults.items():
+            if not overwrite and key in self.parser._defaults:
+                continue
+            self.parser._defaults[key] = value
+
     def get_context(self, object_type, name=None, global_conf=None):
         if self.absolute_name(name):
             return loadcontext(object_type, name,
@@ -390,7 +400,7 @@ class ConfigLoader(_Loader):
                 obj=None,
                 object_type=FILTER_WITH,
                 protocol=None,
-                global_conf=None, local_conf=None,
+                global_conf=global_conf, local_conf=local_conf,
                 loader=self)
             filter_with_context.filter_context = self.filter_context(
                 name=filter_with, global_conf=global_conf)
